[![Build Status](https://app.travis-ci.com/aegis4048/GasCompressibiltiy-py.svg?branch=master)](https://app.travis-ci.com/aegis4048/GasCompressibiltiy-py)

<img src="https://raw.githubusercontent.com/aegis4048/GasCompressibiltiy-py/master/misc/intro_image.png" alt="Alt text" title="Optional title">

# GasCompressibility-py
GasCompressibility-py is a Python library for calculating the gas compressibility factor, $`Z`$, based on real gas law. 

It is designed with practical oil field application in mind, in which the required inputs ($`T`$, $`P`$, and $`\gamma_{g}`$) can be readily obtained from the surface facility. 

The packages is under [MIT License](https://github.com/aegis4048/GasCompressibiltiy-py/blob/main/LICENSE).


# Authors

* __[Eric 'Soobin' Kim](https://github.com/aegis4048)__ - Petroleum engineer with the gas compressor company, [Flogistix](https://flogistix.com/). Primary author of the package. (Contact | aegis4048@gmail.com, Website | [PythonicExcursions](https://aegis4048.github.io/))

# Work in Progress
Currently working on publishing the library to PIP, thanks for your patience.

